@@ -6,15 +6,15 @@ pub mod types;
 pub const EAPI_VERSION: u16 = 1;
 
 pub mod prelude {
+    pub use crate::service::safe_rpc_call;
     pub use crate::service::svc_block;
     pub use crate::service::svc_handle_default_rpc;
-    pub use crate::service::svc_launch;
     pub use crate::service::svc_init_logs;
     pub use crate::service::svc_is_active;
     pub use crate::service::svc_is_terminating;
+    pub use crate::service::svc_launch;
     pub use crate::service::svc_mark_ready;
     pub use crate::service::svc_mark_terminating;
-    pub use crate::service::svc_safe_rpc_call;
     pub use crate::service::svc_start_signal_handlers;
     pub use crate::service::svc_terminate;
     pub use crate::service::svc_wait_core;
