@@ -93,7 +93,7 @@ pub fn svc_handle_default_rpc(method: &str, info: &services::ServiceInfo) -> Rpc
 }
 
 #[inline]
-pub async fn svc_safe_rpc_call(
+pub async fn safe_rpc_call(
     rpc: &RpcClient,
     target: &str,
     method: &str,
@@ -119,7 +119,7 @@ pub async fn svc_wait_core(rpc: &RpcClient, timeout: Duration, wait_forever: boo
                 "core load wait aborted, the service is not active",
             ));
         }
-        if let Ok(ev) = svc_safe_rpc_call(
+        if let Ok(ev) = safe_rpc_call(
             rpc,
             "eva.core",
             "test",
@@ -398,7 +398,7 @@ where
 {
     let op = eva_common::op::Op::new(initial.startup_timeout());
     let eva_dir = initial.eva_dir().to_owned();
-    if let Some(ref prepare_command) = initial.prepare_command() {
+    if let Some(prepare_command) = initial.prepare_command() {
         let cmd = format!("cd \"{}\" && {}", eva_dir, prepare_command);
         let res = bmart::process::command("sh", ["-c", &cmd], op.timeout()?, None, None).await?;
         if !res.ok() {
@@ -409,7 +409,7 @@ where
         }
     }
     initial
-        .extend_config(op.timeout()?, &Path::new(&eva_dir))
+        .extend_config(op.timeout()?, Path::new(&eva_dir))
         .await?;
     launcher(initial).await
 }
